/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.lang.reflect.InvocationTargetException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.*;
import nl.cloudfarming.client.fleet.machine.windows.OverviewPanel;
import nl.cloudfarming.client.fleet.machine.windows.PropertyTableModel;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.nodes.Node;
import org.openide.nodes.Node.Property;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

@MultiViewElement.Registration(
    displayName = "#LBL_Vehicle_Data",
iconBase = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png",
mimeType = "application/x-agrosense-vehicle",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "Vehicle",
position = 1000)
@Messages({"LBL_Vehicle_Data=Data", "unknownPropertyValue=Unknown"})
public final class VehicleDataElement extends JPanel implements MultiViewElement {

    private VehicleDataObject obj;
    private Vehicle vehicle;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private PropertyTableModel propertyTableModel = new PropertyTableModel();
    private static final Logger LOGGER = Logger.getLogger(VehicleDataElement.class.getName());

    public VehicleDataElement(Lookup lkp) {
        obj = lkp.lookup(VehicleDataObject.class);
        vehicle = obj.getLookup().lookup(Vehicle.class);

        setLayout(new BorderLayout());

        OverviewPanel overviewPanel = new OverviewPanel();
        overviewPanel.setPropertyListModel(propertyTableModel);
        SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
                updateData();
            }
        });

        ASBodyPanel overviewDecorator = new ASBodyPanel(overviewPanel);
        overviewDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png", true));
        add(overviewDecorator);

        vehicle.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                updateData();
                updateName();
            }
        });

    }

    private void updateData() {

        Node.PropertySet[] propertySets = vehicle.createSheet().toArray();
        for (Node.PropertySet propertySet : propertySets) {
            for (Property<?> property : propertySet.getProperties()) {
                String propertyName = property.getDisplayName();
                String propertyValue = getPropertyValue(property);
                propertyTableModel.addRow(propertyName, propertyValue);
            }
        }
    }

    private boolean propertyHasValidValue(Property<?> property) throws IllegalAccessException, InvocationTargetException {
        return property.getValue() != null && !property.getValue().toString().trim().isEmpty();
    }

    private String getPropertyValue(Property<?> property) {
        String propertyValue = Bundle.unknownPropertyValue();
        try {
            if (propertyHasValidValue(property)) {
                propertyValue = property.getValue().toString();
            }
        } catch (IllegalAccessException | InvocationTargetException ex) {
            LOGGER.log(Level.WARNING, "Could not access property value for machine", ex.getMessage());
        } finally {
            return propertyValue;
        }
    }

    @Override
    public String getName() {
        return "VehicleVisualElement";
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 400, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 300, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
        OpenCloseHandler.Event.triggerOpen(obj.getNodeDelegate());
    }

    @Override
    public void componentClosed() {
        OpenCloseHandler.Event.triggerClose(obj.getNodeDelegate());
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(vehicle.getName());
            tc.setDisplayName(vehicle.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
