/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.io.IOException;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.vehicle.tree.VehicleNode;
import nl.cloudfarming.client.geoviewer.SimpleLayer;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiDataObject;
import org.openide.loaders.MultiFileLoader;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.lookup.AbstractLookup;
import org.openide.util.lookup.InstanceContent;
import org.openide.util.lookup.ProxyLookup;

public class VehicleDataObject extends MultiDataObject {
    
    private final InstanceContent ic = new InstanceContent();
    private final Lookup lkp = new AbstractLookup(ic);
    
    public VehicleDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        registerEditor("application/x-agrosense-vehicle", true);
        VehicleManagerImpl vehicleManager = Lookup.getDefault().lookup(VehicleManagerImpl.class);
        Vehicle vehicle = vehicleManager.load(pf);
        ic.add(vehicle);
        ic.add(vehicle.getGeometrical());
        ic.add(new SimpleLayer(vehicle.getName()));
    }
    
    @Override
    protected int associateLookup() {
        return 1;
    }
    
    @Override
    protected Node createNodeDelegate() {
        return new VehicleNode(super.createNodeDelegate());
    }
    
    @Override
    public Lookup getLookup() {
        return new ProxyLookup(super.getLookup(), lkp);
    }
}
