/*
 *  Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 *  Licensed under the Eclipse Public License - v 1.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 * 
 *           http://www.eclipse.org/legal/epl-v10.html
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.fleet.machine.windows.ImagePanel;
import nl.cloudfarming.client.fleet.machine.windows.OverviewPanel;
import nl.cloudfarming.client.fleet.machine.windows.PropertyTableModel;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@MultiViewElement.Registration(
    displayName = "#LBL_Vehicle_Image",
iconBase = "nl/cloudfarming/client/fleet/vehicle/fleet.png",
mimeType = "application/x-agrosense-vehicle",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "VehicleImage",
position = 2000)
@NbBundle.Messages("LBL_Vehicle_Image=Image")
public final class VehicleImageElement extends JPanel implements MultiViewElement {

    private VehicleDataObject obj;
    private Vehicle vehicle;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;    
    private ImagePanel imagePanel = new ImagePanel();
    
    public VehicleImageElement(Lookup lkp) {
        obj = lkp.lookup(VehicleDataObject.class);
        vehicle = obj.getLookup().lookup(Vehicle.class);
        assert obj != null;
        assert vehicle != null;

        setLayout(new BorderLayout());
        
        imagePanel.setImage(vehicle.getImage());
        
        vehicle.addPropertyChangeListener(Vehicle.PROP_IMAGE, new PropertyChangeListener() {

            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                imagePanel.setImage((ImageIcon)evt.getNewValue());
            }
        });
        

        ASBodyPanel overviewDecorator = new ASBodyPanel(imagePanel);
        overviewDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/vehicle/fleet.png", true));
        add(overviewDecorator);

    }    
    
    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
        OpenCloseHandler.Event.triggerOpen(obj.getNodeDelegate());
    }

    @Override
    public void componentClosed() {
        OpenCloseHandler.Event.triggerClose(obj.getNodeDelegate());
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }        
    }
    
    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(vehicle.getName());
            tc.setDisplayName(vehicle.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }    

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
    
}
