/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import javax.swing.Action;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryChildren;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryNode;
import nl.cloudfarming.client.fleet.model.Machine.MachineMetaInfo;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.vehicle.wizard.VehicleWizardAction;
import org.netbeans.api.project.Project;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Wytse Visser
 */
public final class VehicleCategoryNode extends MachineCategoryNode {

    public VehicleCategoryNode(Node original, Project project) {
        super(original, new MachineCategoryChildren(original, Vehicle.class), project, Lookups.fixed(new VehicleCategoryInfo()));
    }

    @Override
    public Action[] getActions(boolean context) {
        return new Action[]{
                    new OpenAction(),
                    null,
                    new VehicleWizardAction(getProject())
                };
    }

    @NbBundle.Messages("displayName=Vehicles")
    public static class VehicleCategoryInfo implements MachineMetaInfo {

        private final String ICON_SMALL = "nl/cloudfarming/client/fleet/vehicle/folder_vehicles16.png";
        private final String ICON_LARGE = "nl/cloudfarming/client/fleet/vehicle/folder_vehicles32.png";

        @Override
        public String getDisplayName() {
            return Bundle.displayName();
        }

        @Override
        public String getSmallIconResource() {
            return ICON_SMALL;
        }

        @Override
        public String getLargeIconResource() {
            return ICON_LARGE;
        }
    }
}