/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.model.FleetManager;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz & Wytse Visser
 */
@NodeFactory.Registration(projectType = "nl-cloudfarming-client-fleet")
public class VehicleCategoryNodeFactory implements NodeFactory {

    private static final String DIR_NAME = "Vehicles";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.vehicle");

    @Override
    public NodeList<?> createNodes(Project project) {
        try {
            createDirectoryIfNotExists(project);
            DataFolder vehiclesFolder = DataFolder.findFolder(getVehicleDirectory(project));
            return NodeFactorySupport.fixedNodeList(new VehicleCategoryNode(
                    vehiclesFolder.getNodeDelegate(),
                    project));

        } catch (IOException ex) {
            LOGGER.log(Level.SEVERE, "Could not create subdirectory for vehicles", ex.getMessage());
            return NodeFactorySupport.fixedNodeList();
        }
    }

    private static void createDirectoryIfNotExists(Project project) throws IOException {
        FileObject fleetDir = getFleetDirectory(project);

        if (fleetDir.getFileObject(DIR_NAME) == null) {
            fleetDir.createFolder(DIR_NAME);
        }
    }

    private static FileObject getFleetDirectory(Project project) throws IOException {
        FileObject fleetDir = project.getProjectDirectory().getFileObject(FleetManager.FLEET_DIR);
        if (fleetDir == null) {
            fleetDir = project.getProjectDirectory().createFolder(FleetManager.FLEET_DIR);
        }

        return fleetDir;
    }

    public static FileObject getVehicleDirectory(Project project) throws IOException {
        createDirectoryIfNotExists(project);
        return project.getProjectDirectory().getFileObject(FleetManager.FLEET_DIR).getFileObject(DIR_NAME);
    }

    public static String getDirectoryName() {
        return DIR_NAME;
    }
}
