/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import nl.cloudfarming.client.fleet.machine.tree.MachineNode;
import nl.cloudfarming.client.fleet.model.Machine.MachineMetaInfo;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import org.openide.nodes.Node;
import org.openide.util.Lookup;

/**
 *
 * @author Maciek Dulkiewicz && Wytse Visser
 */
public class VehicleNode extends MachineNode {
    
    public VehicleNode(Node node) {
        super(node);
        assert node.getLookup().lookup(Vehicle.class)!=null:"VehicleNode should have a Vehicle instance in its lookup";
    }
    
    @Override
    protected void saveMachine() {
        Lookup.getDefault().lookup(VehicleManager.class).save((Vehicle) getMachine());
    }

    @Override
    protected MachineMetaInfo getMetaInfo() {
        return new VehicleInfo();
    }
    
    public class VehicleInfo implements MachineMetaInfo {

        private final String ICON_SMALL = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png";
        private final String ICON_LARGE = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_332.png";

        @Override
        public String getDisplayName() {
            return getMachine().getName();
        }

        @Override
        public String getSmallIconResource() {
            return ICON_SMALL;
        }

        @Override
        public String getLargeIconResource() {
            return ICON_LARGE;
        }
    }
}