/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.io.IOException;
import java.util.Date;
import javax.swing.ImageIcon;
import nl.cloudfarming.client.fleet.machine.MachineDataService.Model;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardAction;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardIterator;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import nl.cloudfarming.client.fleet.vehicle.tree.VehicleCategoryNodeFactory;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

@NbBundle.Messages({"wizardTitle=New vehicle"})
public final class VehicleWizardAction extends MachineWizardAction {

    public VehicleWizardAction(Project project) {
        super(project, Bundle.wizardTitle());
    }

    @Override
    protected void createMachine(WizardDescriptor wiz) throws IOException {
        EnterpriseIdProvider eip = getProject().getLookup().lookup(EnterpriseIdProvider.class);
        String name = wiz.getProperty(Machine.PROP_NAME).toString();
        Vehicle vehicle = new Vehicle(eip, name);
        Model model = (Model) wiz.getProperty(MachineWizardIterator.PROP_MODEL);
        vehicle.setType(model.getType());
        vehicle.setBrand(model.getBrand());
        vehicle.setModelNumber(model.getModelNumber());
        vehicle.setImage((ImageIcon) model.getProperty(Machine.PROP_IMAGE));
        vehicle.setYear(Integer.parseInt(wiz.getProperty(Machine.PROP_YEAR).toString()));
        vehicle.setPurchaseDate((Date) wiz.getProperty(Machine.PROP_PURCHASEDATE));
        vehicle.setPurchasePrice(Double.parseDouble(wiz.getProperty(Machine.PROP_PURCHASEPRICE).toString()));
        vehicle.setMileage(Integer.parseInt(wiz.getProperty(Machine.PROP_MILEAGE).toString()));

        vehicle.setHorsepower((int) readProperty(Vehicle.PROP_HORSEPOWER, wiz, model));
        vehicle.setDisplacement((double) readProperty(Vehicle.PROP_DISPLACEMENT, wiz, model));
        vehicle.setFuelTankCapacity((int) readProperty(Vehicle.PROP_FUELTANKCAPACITY, wiz, model));

        addDynamicProperties(vehicle, wiz);

        Lookup.getDefault().lookup(VehicleManager.class).save(vehicle);
    }

    @Override
    public MachineWizardFactory getWizardFactory() {
        return new VehicleWizardFactory(getProject());
    }
}
