/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.util.LinkedList;
import java.util.List;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardOverviewPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardStartPanel;
import nl.cloudfarming.client.fleet.model.MachineProvider;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.vehicle.VehicleDataService;
import nl.cloudfarming.client.fleet.vehicle.VehicleManagerImpl;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;

/**
 *
 * @author Wytse Visser
 */
class VehicleWizardFactory extends MachineWizardFactory {

    public VehicleWizardFactory(Project project) {
        super(project);
    }

    @Override
    public MachineWizardPanel createOverviewPanel() {
        MachineWizardOverviewPanel panel = new MachineWizardOverviewPanel();
        panel.addProperty(Vehicle.PROP_YEAR, "Year");
        panel.addProperty(Vehicle.PROP_PURCHASEDATE, "Purchase date");
        panel.addProperty(Vehicle.PROP_PURCHASEPRICE, "Purchase price");
        panel.addProperty(Vehicle.PROP_MILEAGE, "Mileage");
        panel.addProperty(Vehicle.PROP_HORSEPOWER, "Horsepower");
        panel.addProperty(Vehicle.PROP_DISPLACEMENT, "Displacement (L)");
        panel.addProperty(Vehicle.PROP_FUELTANKCAPACITY, "Fuel tank capacity (L)");

        return panel;
    }

    @Override
    public List<WizardDescriptor.Panel<WizardDescriptor>> createInitialPanels() {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new LinkedList<>();
        panels.add(new MachineWizardStartPanel(this));
        panels.add(new VehicleWizardPanel2());
        return panels;
    }

    @Override
    public Class<? extends MachineDataService> getDataServiceClass() {
        return VehicleDataService.class;
    }

    @Override
    public Class<? extends MachineProvider> getMachineProviderClass() {
        return VehicleManagerImpl.class;
    }

}
